@@ -6,7 +6,10 @@
 
 package NetPacket;
 BEGIN {
-  $NetPacket::VERSION = '0.43.1';
+  $NetPacket::AUTHORITY = 'cpan:YANICK';
+}
+{
+  $NetPacket::VERSION = '1.3.0';
 }
 # ABSTRACT: assemble/disassemble network packets at the protocol level
 
@@ -104,19 +107,17 @@ sub ntohs
 
 1;
 
-# autoloaded methods go after the END token (&& pod) below
 
-__END__
 
 =pod
 
 =head1 NAME
 
-NetPacket - modules to assemble/disassemble network packets at the protocol level.
+NetPacket - assemble/disassemble network packets at the protocol level
 
 =head1 VERSION
 
-version 0.43.1
+version 1.3.0
 
 =head1 SYNOPSIS
 
@@ -195,12 +196,12 @@ however contains header fields and a payload.
 
 =back
 
-=head2 Tags
+=head1 SEE ALSO
 
-=head1 COPYRIGHT
+Joel Knight has a patch for NetPacket for IPv6 support available
+at http://www.packetmischief.ca/code/netpacket/.
 
-This is free software; you can redistribute it and/or modify it 
-under the same terms as the Perl 5 programming language system itself.
+=head1 COPYRIGHT AND LICENSE
 
 Copyright (c) 2001 Tim Potter and Stephanie Wehner.
 
@@ -208,6 +209,13 @@ Copyright (c) 1995,1996,1997,1998,1999 ANU and CSIRO on behalf of
 the participants in the CRC for Advanced Computational Systems
 ('ACSys').
 
+This module is free software.  You can redistribute it and/or
+modify it under the terms of the Artistic License 2.0.
+
+This program is distributed in the hope that it will be useful,
+but without any warranty; without even the implied warranty of
+merchantability or fitness for a particular purpose.
+
 =head1 AUTHORS
 
 Tim Potter <tpot@samba.org>
@@ -216,4 +224,9 @@ Stephanie Wehner <atrak@itsx.com>
 
 Yanick Champoux <yanick@cpan.org>
 
-=cut
\ No newline at end of file
+=cut
+
+
+__END__
+
+
